version 18.0

clear all
set matsize 11000
set processors 3
set scheme stcolor_alt
set varabbrev on

global dir "SET DIRECTORY PATH"

cd "$dir"

sysdir set PLUS "${dir}/Do files/ado"
/*
ssc install gtools
ssc install kountry
ssc install outreg2
ssc install reghdfe 
ssc install ftools
ssc install coefplot
ssc install ppmlhdfe
*/

////////////////////////////////////////////////////////////////////////////////
***********************
////CEPII: Gravity variables
unzipfile "gravdata_cepii.zip", replace
use "gravdata", clear
keep iso3_o iso3_d year contig distw comlang_off
keep if year==2000
drop year
rename (iso3_o iso3_d) (source_iso3 destination_iso3)
tab source_
replace source_iso3="ROU" if source_iso3=="ROM"
replace destination_iso3="ROU" if destination_iso3=="ROM"
replace source_iso3="SRB" if source_iso3=="YUG"
replace destination_iso3="SRB" if destination_iso3=="YUG"
save "gravdata_tmp", replace

use "gravdata", clear
keep if year==2000

replace iso3_o="EU27" if inlist(iso3_o, "AUT", "BEL", "BGR", "HRV", "CYP", "CZE", "DNK")
replace iso3_o="EU27" if inlist(iso3_o, "EST", "FIN", "FRA", "DEU", "GRC", "HUN", "IRL")
replace iso3_o="EU27" if inlist(iso3_o, "ITA", "LVA", "LTU", "LUX", "MLT", "NLD", "POL") 
replace iso3_o="EU27" if inlist(iso3_o, "PRT", "ROM", "SVK", "SVN", "ESP", "SWE")
gcollapse (mean) distw (max) contig comlang_off [aweight=pop_o ], by(iso3_o iso3_d pop_d)


replace iso3_d="EU27" if inlist(iso3_d, "AUT", "BEL", "BGR", "HRV", "CYP", "CZE", "DNK")
replace iso3_d="EU27" if inlist(iso3_d, "EST", "FIN", "FRA", "DEU", "GRC", "HUN", "IRL")
replace iso3_d="EU27" if inlist(iso3_d, "ITA", "LVA", "LTU", "LUX", "MLT", "NLD", "POL") 
replace iso3_d="EU27" if inlist(iso3_d, "PRT", "ROM", "SVK", "SVN", "ESP", "SWE")
gcollapse (mean) distw (max) contig comlang_off [aweight=pop_d ], by(iso3_o iso3_d)

replace contig=0 if iso3_o==iso3_d
replace comlang_off=0 if iso3_o==iso3_d

rename (iso3_o iso3_d) (source_iso3 destination_iso3)
tab source_
replace source_iso3="SRB" if source_iso3=="YUG"
replace destination_iso3="SRB" if destination_iso3=="YUG"
save "gravdataEU27_tmp", replace
erase gravdata.dta
erase gravdata_codebook.doc

********************************************************************************
***NATO
clear 
set obs 2000
gen cou=""
local i=1
foreach var in "United States" " United Kingdom" " Belgium" " Canada" " Denmark" " France" " Iceland" " Italy" " Luxembourg" " Netherlands" " Norway" " Portugal" " Albania" " Lithuania" " Bulgaria" " Montenegro" " Croatia" " Czech Republic" " Poland" " Estonia" " Romania" " Germany" " Slovakia" " Greece" " Slovenia" " Hungary" " Spain" " Turkey" " Latvia" "North Macedonia"{
	replace cou="`var'" in `i'
	local ++i		
}
kountry cou, from(other) stuck
rename _ ii
kountry ii, from(iso3n) to(iso3c)
rename _ iso3
replace iso3="MKD" if iso3==""
drop if cou==""
gen nato=1
keep iso nato

gen source_iso3=iso
gen destination_iso3=iso
fillin source_iso3 destination_iso3
drop if source_iso3==destination_iso3
replace nato=1
keep nato sour dest
save "nato", replace

/////////////////
//GET GDP and Population data: Downloaded on 7/10/2024 
/*
wbopendata, year(2015:2023) language(en - English) topics() indicator(NY.GDP.MKTP.CD; SP.POP.TOTL) long clear 

by countrycode: ipolate ny_gdp_mktp_cd year, gen(ny_gdp_mktp_cd_epolate) epolate
by countrycode: ipolate sp_pop_totl year, gen(sp_pop_totl_epolate) epolate

egen id=group(countrycode)
xtset id year

foreach var of varlist *_epolate{
	gen `var'_lag=l.`var'
}
rename countrycode iso
keep iso year *_epolate* region incomelevelname
save "gdp_pop", replace  
*/

********************************************************************************
********************************************************************************
********************************************************************************
***Merge files
use "FDI_2023", clear 
merge m:1 source_iso3 destination_iso3 using "gravdata_tmp", keep(1 3) nogen
erase gravdata_tmp.dta

merge m:1 source_iso3 destination_iso3 using "nato", keep(1 3) nogen
replace nato=0 if nato==.
erase nato.dta

rename source_iso3 iso
merge m:1 iso year using "gdp_pop", keep(1 3) nogen
rename (iso destination_iso3 ny_gdp_mktp_cd_epolate sp_pop_totl_epolate ny_gdp_mktp_cd_epolate_lag sp_pop_totl_epolate_lag region incomelevelname) (source_iso3 iso GDP_source pop_source GDP_source_lag pop_source_lag region_source incomelevelname_source)

merge m:1 iso year using "gdp_pop", keep(1 3) nogen

rename (iso ny_gdp_mktp_cd_epolate sp_pop_totl_epolate ny_gdp_mktp_cd_epolate_lag sp_pop_totl_epolate_lag region incomelevelname) (destination_iso3 GDP_dest pop_dest GDP_dest_lag pop_dest_lag region_dest incomelevelname_dest)
	   
save "data_regressions", replace 

//ADD EU 27
use "data_regressions", replace 
summ if source==desti
gen source_EU27="EU27" if inlist(source_iso3, "AUT", "BEL", "BGR", "HRV", "CYP", "CZE", "DNK")
replace source_EU27="EU27" if inlist(source_iso3, "EST", "FIN", "FRA", "DEU", "GRC", "HUN", "IRL")
replace source_EU27="EU27" if inlist(source_iso3, "ITA", "LVA", "LTU", "LUX", "MLT", "NLD", "POL") 
replace source_EU27="EU27" if inlist(source_iso3, "PRT", "ROU", "SVK", "SVN", "ESP", "SWE")


gen destination_EU27="EU27" if inlist(destination_iso3, "AUT", "BEL", "BGR", "HRV", "CYP", "CZE", "DNK")
replace destination_EU27="EU27" if inlist(destination_iso3, "EST", "FIN", "FRA", "DEU", "GRC", "HUN", "IRL")
replace destination_EU27="EU27" if inlist(destination_iso3, "ITA", "LVA", "LTU", "LUX", "MLT", "NLD", "POL") 
replace destination_EU27="EU27" if inlist(destination_iso3, "PRT", "ROU", "SVK", "SVN", "ESP", "SWE")

order source_iso3 destination_iso3 source_EU27 destination_EU27
save "data_regressions", replace 

//Pop 1mln
use "data_regressions", replace 
keep if year==2015
keep destination_iso3 pop_dest
duplicates drop
gen dest_pop1=(pop_dest>=1000000 & pop_dest!=.)
keep dest*

merge 1:m destination_iso3 using "data_regressions", nogen
save "data_regressions", replace 
