clear all
set matsize 11000
set processors 3
set scheme stcolor_alt
set varabbrev on

global dir "SET DIRECTORY PATH"



cd "$dir"
********************************************************************************
********************************************************************************
//////////////////////////////////////////
//Figure 1: Same Country, Border, NATO
use "Data/data_regressions", clear 
keep if source_iso3=="USA"

gen capital_investment_all=capital_investment 
replace capital_investment=0 if destination_iso3=="USA"


drop if year<2015

gen capital_investment_Contig=capital_investment if contig==1
gen capital_investment_NATO=capital_investment if nato==1
gen capital_investment_USA=capital_investment_all if destination_iso3=="USA"


gcollapse (sum) capital_investment_Contig capital_investment_NATO capital_investment_USA capital_investment capital_investment_all, by(date year)

gen share_contig=capital_investment_Contig/capital_investment
gen share_nato=capital_investment_NATO/capital_investment
gen share_usa=capital_investment_USA/capital_investment_all

gen period="2015-17" if year<=2017
replace period=`""2018-19" "(Trade War)""' if year>=2018 & year<=2019
replace period=`""2020-21" "(Covid-19)""' if year>=2020 & year<=2021
replace period=`""2022-23" "(Invasion of Ukraine)""' if year>=2022 & year<=2023

gen order_chart=1 if period=="2015-17"
replace order_chart=2 if period==`""2018-19" "(Trade War)""'
replace order_chart=3 if period==`""2020-21" "(Covid-19)""'
replace order_chart=4 if period==`""2022-23" "(Invasion of Ukraine)""'

gcollapse (mean) share*, by(period order_chart)

graph bar (mean) share_usa share_nato share_contig, over(period, sort(order_chart)) legend(order(1 "USA" 2 "NATO countries" 3 "Neighboring countries") rows(1)) ytitle("Share of U.S. Investment") scale(1.2)
graph export "Figures\Figure_1.tif", replace

