clear all
set matsize 11000
set processors 3
set scheme stcolor_alt
set varabbrev on

global dir "SET DIRECTORY PATH"
sysdir set PLUS "${dir}/Do files/ado"


cd "$dir"
********************************************************************************
********************************************************************************
//////////////////////////////////////////
//Figure 2: EVENT STUDY
use "Data/data_regressions", clear

keep if source_iso3=="USA"

gcollapse (sum) capital_investment (mean) contig comlang_off distw nato ,  by(source_iso3 destination_iso3 date year month GDP_dest* pop_dest*)

gen ln_pop=ln(pop_dest)
gen ln_gdp=ln(GDP_dest)
gen ln_fdi=ln(capital_investment+1)

gen same_country=(source_iso3==destination_iso3)

gen ln_distw=ln(distw)

global xxx_vars "ln_distw contig same_country comlang_off nato ln_gdp ln_pop"

forvalue yr=2015(1)2023{
	foreach var of varlist $xxx_vars{
		gen tmp=(year==`yr')
		gen yr_`yr'`var'=tmp*`var'
		drop tmp
		label var yr_`yr'`var' "`yr'"
	}
}

foreach var of varlist yr_2017*{
	replace `var'=0 if year==2017
}


foreach var of varlist $xxx_vars{
	rename yr_*`var' yrR_*
	reghdfe ln_fdi yrR_* yr_* $xxx_vars, a(i.year##i.m) vce(rob)
	estimates store `var'
	rename yrR_* yr_*`var'
}

rename yr_*same_country yrR_*

coefplot (same_country, label("{stMono:I(Same country)}")) (nato, label("{stMono:I(NATO)}")) (contig, label("{stMono:I(Border)}")) , keep(yrR_*) yline(0) ci(95) vertical scale(1.3) omitted ciopts(recast(rcap)) citop scheme(stcolor_alt) legend(rows(1))  
graph export "Figures\Figure_2.tif", replace 
