clear all
set matsize 11000
set processors 3
set scheme stcolor_alt
set varabbrev on

global dir "SET DIRECTORY PATH"
sysdir set PLUS "${dir}/Do files/ado"

cd "$dir"
*********************
***MONTHLY DATA 
use "Data/data_regressions", clear
replace source_iso3=source_EU27 if source_EU27!=""
replace destination_iso3=destination_EU27 if destination_EU27!=""

keep if source_iso3=="USA" | source_iso3=="EU27"

gcollapse (sum) capital_investment jobscreated (max) nato dest_pop1,  by(source_iso3 destination_iso3 date year month ) labelformat(#sourcelabel# ) 
merge m:1 source_iso3 destination_iso3 using "Data/gravdataEU27_tmp", keep(1 3) nogen

gen same_country=(source_iso3==destination_iso3)

gen ln_fdi=ln(capital_investment+1)
gen ln_jobscreated=ln(jobscreated+1)
gen ln_distw=ln(distw)

egen it=group(source_iso3 date)
egen jt=group(destination_iso3 date)
egen ij=group(source_iso3  destination_iso3)

egen id=group(source_iso3 destination_iso3)
xtset id date

replace nato=0 if source_iso3==destination_iso3

gen US=(source_iso3=="USA")

label var ln_distw "ln(distance)"
label var contig "I(Border)"
label var comlang_off "I(Common language)"
label var same_country "I(Same country)"
label var nato "I(NATO)"
label var US "I(US)"
label var ln_fdi "ln(FDI)"
label var ln_jobscreated "ln(jobs)"
 

global text_table "Note: The regression includes source country-time, host country-time, and source country-host country fixed effects. The sample covers bilateral US and EU investment. In column (1), the sample covers the period from January 2015 to February 2020 (Trade War); in column (2), from January 2015 to January 2022 (COVID-19); and in column (3), from January 2015 to December 2023 (Invasion of Ukraine). Robust standard errors, clustered at the source-time level, are reported in parentheses.", "*** p<0.01, ** p<0.05, * p<0.1"

global xxx_vars "same_country contig ln_distw nato comlang_off"

gen spl_post_trade_war=tin(2010m1, 2020m2)
gen spl_post_covid=tin(2010m1, 2022m1)
gen spl_post_russia=tin(2010m1, 2030m7)
gen event=tin(2018m7, 2030m7)


//Table 1
global table "Results\Table_1"
foreach var1 in post_trade_war post_covid post_russia{
cap drop i3_* i2_*
	foreach var2 of varlist $xxx_vars{
		local lab2: var label `var2'
		
		cap drop i3_`var2'
		gen i3_`var2'=event*`var2'*US
		label var i3_`var2'	"I(t>Event) x I(US) x `lab2'"
		
		cap drop i2_`var2'
		gen i2_`var2'=event*`var2'
		label var i2_`var2'	"I(t>Event) x `lab2'"
		
		cap drop i2_US
		gen i2_US=event*US
		label var i2_US	"I(t>Event) x I(US)"
		
		cap drop i2_US_`var2'
		gen i2_US_`var2'=US*`var2'
		label var i2_US_`var2'	"I(US) x `lab2'"
	}
	reghdfe ln_fdi i3_* i2_* $xxx_vars if spl_`var1'==1, a(it jt ij) cl(it) 
	outreg2 using "$table.xls", ctitle(`var1') nonotes addnote("$text_table") dec(3) excel append label 	drop(o.*) nocons
}


cap drop i3_* i2_*
cap erase "$table.txt"


//Table 2
label var capital_investment "FDI"
global table "Results\Table_2"
foreach var1 in post_trade_war post_covid post_russia{
cap drop i3_* i2_*
	foreach var2 of varlist $xxx_vars{
		local lab2: var label `var2'
		
		cap drop i3_`var2'
		gen i3_`var2'=event*`var2'*US
		label var i3_`var2'	"I(t>Event) x I(US) x `lab2'"
		
		cap drop i2_`var2'
		gen i2_`var2'=event*`var2'
		label var i2_`var2'	"I(t>Event) x `lab2'"
		
		cap drop i2_US
		gen i2_US=event*US
		label var i2_US	"I(t>Event) x I(US)"
		
		cap drop i2_US_`var2'
		gen i2_US_`var2'=US*`var2'
		label var i2_US_`var2'	"I(US) x `lab2'"
	}
	ppmlhdfe capital_investment i3_* i2_* $xxx_vars if spl_`var1'==1, a(it jt ij) cl(it) 
	outreg2 using "$table.xls", ctitle(PPML, `var1') nonotes addnote("$text_table") dec(3) excel append label drop(o.*) nocons
}
cap drop i3_* i2_*


foreach var1 in post_trade_war post_covid post_russia{
cap drop i3_* i2_*
	foreach var2 of varlist $xxx_vars{
		local lab2: var label `var2'
		
		cap drop i3_`var2'
		gen i3_`var2'=event*`var2'*US
		label var i3_`var2'	"I(t>Event) x I(US) x `lab2'"
		
		cap drop i2_`var2'
		gen i2_`var2'=event*`var2'
		label var i2_`var2'	"I(t>Event) x `lab2'"
		
		cap drop i2_US
		gen i2_US=event*US
		label var i2_US	"I(t>Event) x I(US)"
		
		cap drop i2_US_`var2'
		gen i2_US_`var2'=US*`var2'
		label var i2_US_`var2'	"I(US) x `lab2'"
	}
	reghdfe ln_fdi i3_* i2_* $xxx_vars if spl_`var1'==1 & dest_pop1==1, a(it jt ij) cl(it) 
	outreg2 using "$table.xls", ctitle("Small states excluded", `var1') nonotes addnote("$text_table") dec(3) excel append label drop(o.*) nocons
}
cap drop i3_* i2_*
cap erase "$table.txt"

//Table 3
global table "Results\Table_3"
foreach var1 in post_trade_war post_covid post_russia{
cap drop i3_* i2_*
	foreach var2 of varlist $xxx_vars{
		local lab2: var label `var2'
		
		cap drop i3_`var2'
		gen i3_`var2'=event*`var2'*US
		label var i3_`var2'	"I(t>Event) x I(US) x `lab2'"
		
		cap drop i2_`var2'
		gen i2_`var2'=event*`var2'
		label var i2_`var2'	"I(t>Event) x `lab2'"
		
		cap drop i2_US
		gen i2_US=event*US
		label var i2_US	"I(t>Event) x I(US)"
		
		cap drop i2_US_`var2'
		gen i2_US_`var2'=US*`var2'
		label var i2_US_`var2'	"I(US) x `lab2'"
	}
	reghdfe ln_jobscreated i3_* i2_* $xxx_vars if spl_`var1'==1, a(it jt ij) cl(it) 
	outreg2 using "$table.xls", ctitle(`var1') nonotes addnote("$text_table") dec(3) excel append label 	drop(o.*) nocons
}


cap drop i3_* i2_*
cap erase "$table.txt"


cap erase "$table.txt"
cap erase "Data/gravdataEU27_tmp.dta"
cap erase "Data/data_regressions.dta"
